-module(test_app).

-behaviour(application).

%% application callbacks
-export([start/2, stop/1]).

%% supervisor callbacks
-export([init/1]).

   
%%%-------------------------------------------------------------------
%%% Callback functions from application
%%%-------------------------------------------------------------------

%%--------------------------------------------------------------------
%% @spec start(Type, StartArgs) -> Result
%%         Result = {ok, Pid}        |
%%                  {ok, Pid, State} |
%%                  {error, Reason}
%% @doc Start application callback
%% @end
%% @private
%%--------------------------------------------------------------------
start(_Type, StartArgs) ->
    supervisor:start_link({local, ?MODULE}, ?MODULE, [StartArgs]).

%%--------------------------------------------------------------------
%% @spec stop(Reason) -> any
%% @doc Stop application callback
%% @end
%% @private
%%--------------------------------------------------------------------
stop(_Reason) ->
    ok.

%%%-------------------------------------------------------------------
%%% Callback functions from supervisor
%%%-------------------------------------------------------------------

%%--------------------------------------------------------------------
%% Func: init/1
%% Returns: {ok,  {SupFlags,  [ChildSpec]}} |
%%          ignore                          |
%%          {error, Reason}
%% @private
%%--------------------------------------------------------------------
init(_StartArgs) ->
    File = "priv/httpd.config",
    {ok, {
         _SupFlags = {one_for_one, 1, 10}, [{
            % dynamic configuration loader
            conf_srv,                      % Id       = internal id
            {httpd, start_link, [File]},   % StartFun = {M, F, A}
            permanent,                     % Restart  = permanent | transient | temporary
            2000,                          % Shutdown = brutal_kill | int() >= 0 | infinity
            worker,                        % Type     = worker | supervisor
            []                             % Modules  = [Module] | dynamic
        }]
    }}.

%%%-------------------------------------------------------------------
%%% Internal functions
%%%-------------------------------------------------------------------

